@@ -1,10 +1,5 @@
 package Catalyst::Controller::Validation::DFV;
-{
-  $Catalyst::Controller::Validation::DFV::VERSION = '0.0.8';
-}
-{
-  $Catalyst::Controller::Validation::DFV::DIST = 'Catalyst-Controller-Validation-DFV';
-}
+$Catalyst::Controller::Validation::DFV::VERSION = '0.0.9';
 use strict;
 use warnings;
 
@@ -28,6 +23,8 @@ sub form_check :Private {
     return;
 }
 
+
+
 sub add_form_invalid :Private {
     my ($self, $c, $invalid_key, $invalid_value) = @_;
 
@@ -84,13 +81,15 @@ sub refill_form :Private {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Catalyst::Controller::Validation::DFV - Form validation and refilling
 
 =head1 VERSION
 
-version 0.0.8
+version 0.0.9
 
 =head1 SYNOPSIS
 
@@ -154,18 +153,36 @@ version 0.0.8
 
 Form-validation using a Catalyst controller and Data::FormValidator
 
+=head1 Methods
+
+=head2 add_form_invalid
+
+=head2 validation_errors_to_html
+
+=head2 refill_form
+
 =head1 EXAMPLES
 
 There are L<Template::Toolkit> file examples in the examples/ directory of
 this distribution.
 
+=begin markdown
+
+## BUILD STATUS
+
+### master
+
+[![Build status](https://badge.buildkite.com/a51523ccfc452014358d9666ac0a51ca30bc409da860c34b7d.svg)](https://buildkite.com/chizography/catalyst-validation-dfv)
+
+=end markdown
+
 =head1 AUTHOR
 
 Chisel <chisel@chizography.net>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Chisel Wright.
+This software is copyright (c) 2016 by Chisel Wright.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
@@ -174,4 +191,5 @@ the same terms as the Perl 5 programming language system itself.
 
 __END__
 
+
 # vim: ts=8 sts=4 et sw=4 sr sta
